@@ -42,7 +42,7 @@ void ExampleApplication::on_startup()
     sigc::mem_fun(*this, &ExampleApplication::on_action_quit) );
 
   
-  Glib::RefPtr<Gio::Menu> app_menu = Gio::Menu::create();
+  auto app_menu = Gio::Menu::create();
   app_menu->append("_Something", "app.something");
   app_menu->append("_Quit", "app.quit");
 
@@ -50,16 +50,16 @@ void ExampleApplication::on_startup()
 
 
   //Create the per-Window menu:
-  Glib::RefPtr<Gio::Menu> win_menu = Gio::Menu::create();
+  auto win_menu = Gio::Menu::create();
 
-  Glib::RefPtr<Gio::Menu> submenu_file = Gio::Menu::create();
+  auto submenu_file = Gio::Menu::create();
   submenu_file->append("_New", "win.new");
   submenu_file->append("_Close", "win.close");
   win_menu->append_submenu("File", submenu_file);
 
-  Glib::RefPtr<Gio::Menu> submenu_edit = Gio::Menu::create();
+  auto submenu_edit = Gio::Menu::create();
   submenu_edit->append("_Cut", "win.cut");
-  Glib::RefPtr<Gio::MenuItem> item = Gio::MenuItem::create("_Copy", "win.copy");
+  auto item = Gio::MenuItem::create("_Copy", "win.copy");
   //Setting "accel" works, but might be deprecated soon: See https://bugzilla.gnome.org/show_bug.cgi?id=708908
   //When it is deprecated, use Gtk::Application::set_accel_for_action() instead.
   item->set_attribute_value("accel", Glib::Variant<Glib::ustring>::create("<Primary>c"));
@@ -69,7 +69,7 @@ void ExampleApplication::on_startup()
   submenu_edit->append_item(item);
   win_menu->append_submenu("Edit", submenu_edit);
 
-  Glib::RefPtr<Gio::Menu> submenu_notification = Gio::Menu::create();
+  auto submenu_notification = Gio::Menu::create();
   submenu_notification->append("_Send", "win.send-note");
   submenu_notification->append("_Withdraw", "win.withdraw-note");
   win_menu->append_submenu("Notification", submenu_notification);
@@ -78,7 +78,7 @@ void ExampleApplication::on_startup()
 
   //Create an action with a parameter. This action can be activated from
   //a Gio::Notification, sent by the Notification/win.send-note menu selection.
-  Glib::RefPtr<Gio::SimpleAction> action_print =
+  auto action_print =
     Gio::SimpleAction::create("print", Glib::VARIANT_TYPE_STRING);
   action_print->signal_activate().connect(
     sigc::mem_fun(*this, &ExampleApplication::on_action_print));
@@ -87,7 +87,7 @@ void ExampleApplication::on_startup()
 
 void ExampleApplication::create_window()
 {
-  ExampleWindow* window = new ExampleWindow();
+  auto window = new ExampleWindow();
   window->set_default_size(300, 100);
 
   //Make sure that the application runs for as long this window is still open:
@@ -132,7 +132,7 @@ void ExampleApplication::on_action_quit()
   // counts in both of them. If we want the destructors to be called, we
   // must remove the window from the application. One way of doing this
   // is to hide the window.
-  std::vector<Gtk::Window*> windows = get_windows();
+  auto windows = get_windows();
   if (windows.size() > 0)
     windows[0]->hide(); // In this simple case, we know there is only one window.
 }
