@@ -2,7 +2,7 @@
 
 int main(int argc, char *argv[])
 {
-  Glib::RefPtr<Gtk::Application> app =
+  auto app =
     Gtk::Application::create(argc, argv,
       "org.gtkmm.examples.base");
 
