@@ -1,7 +1,7 @@
 #include <gtkmm.h>
 #include <iostream>
 
-Gtk::Dialog* pDialog = 0;
+Gtk::Dialog* pDialog = nullptr;
 
 static
 void on_button_clicked()
@@ -12,10 +12,10 @@ void on_button_clicked()
 
 int main (int argc, char **argv)
 {
-  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
 
   //Load the GtkBuilder file and instantiate its widgets:
-  Glib::RefPtr<Gtk::Builder> refBuilder = Gtk::Builder::create();
+  auto refBuilder = Gtk::Builder::create();
   try
   {
     refBuilder->add_from_file("basic.glade");
@@ -41,7 +41,7 @@ int main (int argc, char **argv)
   if(pDialog)
   {
     //Get the GtkBuilder-instantiated Button, and connect a signal handler:
-    Gtk::Button* pButton = 0;
+    Gtk::Button* pButton = nullptr;
     refBuilder->get_widget("quit_button", pButton);
     if(pButton)
     {
