@@ -28,7 +28,7 @@ public:
 
 protected:
   //Override default signal handler:
-  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
+  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
 
   Glib::RefPtr<Gdk::Pixbuf> m_image;
 };
