@@ -41,28 +41,28 @@ ExampleWindow::ExampleWindow()
   show_all_children();
 }
 
-bool ExampleWindow::on_key_press_event(GdkEventKey* event)
+bool ExampleWindow::on_key_press_event(GdkEventKey* key_event)
 {
   //GDK_MOD1_MASK -> the 'alt' key(mask)
   //GDK_KEY_1 -> the '1' key
   //GDK_KEY_2 -> the '2' key
 
   //select the first radio button, when we press alt + 1
-  if((event->keyval == GDK_KEY_1) &&
-    (event->state &(GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_MOD1_MASK)
+  if((key_event->keyval == GDK_KEY_1) &&
+    (key_event->state &(GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_MOD1_MASK)
   {
     m_first.set_active();
     //returning true, cancels the propagation of the event
     return true;
   }
-  else if((event->keyval == GDK_KEY_2) &&
-    (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_MOD1_MASK)
+  else if((key_event->keyval == GDK_KEY_2) &&
+    (key_event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_MOD1_MASK)
   {
     //and the second radio button, when we press alt + 2
     m_second.set_active();
     return true;
   }
-  else if(event->keyval == GDK_KEY_Escape)
+  else if(key_event->keyval == GDK_KEY_Escape)
   {
     //close the window, when the 'esc' key is pressed
     hide();
@@ -70,7 +70,7 @@ bool ExampleWindow::on_key_press_event(GdkEventKey* event)
   }
 
   //if the event has not been handled, call the base class
-  return Gtk::Window::on_key_press_event(event);
+  return Gtk::Window::on_key_press_event(key_event);
 }
 
 ExampleWindow::~ExampleWindow()
