@@ -20,7 +20,7 @@
 ExampleWindow::ExampleWindow()
 : m_Box(Gtk::ORIENTATION_VERTICAL),
   m_Label("Right-click to see the popup menu."),
-  m_pMenuPopup(0)
+  m_pMenuPopup(nullptr)
 {
   set_title("popup example");
   set_default_size(200, 200);
@@ -38,7 +38,7 @@ ExampleWindow::ExampleWindow()
 
   //Fill menu:
 
-  Glib::RefPtr<Gio::SimpleActionGroup> refActionGroup =
+  auto refActionGroup =
     Gio::SimpleActionGroup::create();
 
   //File|New sub menu:
@@ -91,9 +91,9 @@ ExampleWindow::ExampleWindow()
   }
 
   //Get the menu:
-  Glib::RefPtr<Glib::Object> object =
+  auto object =
     m_refBuilder->get_object("menu-examplepopup");
-  Glib::RefPtr<Gio::Menu> gmenu =
+  auto gmenu =
     Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
   if(!gmenu)
     g_warning("GMenu not found");
@@ -112,9 +112,9 @@ void ExampleWindow::on_menu_file_popup_generic()
    std::cout << "A popup menu item was selected." << std::endl;
 }
 
-bool ExampleWindow::on_button_press_event(GdkEventButton* event)
+bool ExampleWindow::on_button_press_event(GdkEventButton* button_event)
 {
-  if( (event->type == GDK_BUTTON_PRESS) && (event->button == 3) )
+  if( (button_event->type == GDK_BUTTON_PRESS) && (button_event->button == 3) )
   {
     if(!m_pMenuPopup->get_attach_widget())
     {
@@ -122,7 +122,7 @@ bool ExampleWindow::on_button_press_event(GdkEventButton* event)
     }
 
     if(m_pMenuPopup)
-      m_pMenuPopup->popup(event->button, event->time);
+      m_pMenuPopup->popup(button_event->button, button_event->time);
 
 
     return true; //It has been handled.
