@@ -52,7 +52,7 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   insert_action_group("example", m_refActionGroup);
 
   //Define how the actions are presented in the menus and toolbars:
-  Glib::RefPtr<Gtk::Builder> m_refBuilder = Gtk::Builder::create();
+  m_refBuilder = Gtk::Builder::create();
 
   //Layout the actions in a menubar and toolbar:
   const char* ui_info =
@@ -130,20 +130,20 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   }
 
   //Get the menubar:
-  Glib::RefPtr<Glib::Object> object = m_refBuilder->get_object("menubar");
-  Glib::RefPtr<Gio::Menu> gmenu = Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
+  auto object = m_refBuilder->get_object("menubar");
+  auto gmenu = Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
   if (!gmenu)
     g_warning("GMenu not found");
   else
   {
-    Gtk::MenuBar* pMenuBar = Gtk::manage(new Gtk::MenuBar(gmenu));
+    auto pMenuBar = Gtk::manage(new Gtk::MenuBar(gmenu));
 
     //Add the MenuBar to the window:
     m_Box.pack_start(*pMenuBar, Gtk::PACK_SHRINK);
   }
 
   //Get the toolbar and add it to a container widget:
-  Gtk::Toolbar* toolbar = 0;
+  Gtk::Toolbar* toolbar = nullptr;
   m_refBuilder->get_widget("toolbar", toolbar);
   if (!toolbar)
     g_warning("GtkToolbar not found");
