@@ -27,7 +27,7 @@ ExampleWindow::ExampleWindow() :
   m_TextView(),
   m_Dispatcher(),
   m_Worker(),
-  m_WorkerThread(0)
+  m_WorkerThread(nullptr)
 {
   set_title("Multi-threaded example");
   set_border_width(5);
@@ -70,7 +70,7 @@ ExampleWindow::ExampleWindow() :
   m_Dispatcher.connect(sigc::mem_fun(*this, &ExampleWindow::on_notification_from_worker_thread));
 
   // Create a text buffer mark for use in update_widgets().
-  Glib::RefPtr<Gtk::TextBuffer> buffer = m_TextView.get_buffer();
+  auto buffer = m_TextView.get_buffer();
   buffer->create_mark("last_line", buffer->end(), /* left_gravity= */ true);
 
   update_start_stop_buttons();
@@ -109,7 +109,7 @@ void ExampleWindow::on_stop_button_clicked()
 
 void ExampleWindow::update_start_stop_buttons()
 {
-  const bool thread_is_running = m_WorkerThread != 0;
+  const bool thread_is_running = m_WorkerThread != nullptr;
 
   m_ButtonStart.set_sensitive(!thread_is_running);
   m_ButtonStop.set_sensitive(thread_is_running);
@@ -125,13 +125,13 @@ void ExampleWindow::update_widgets()
 
   if (message_from_worker_thread != m_TextView.get_buffer()->get_text())
   {
-    Glib::RefPtr<Gtk::TextBuffer> buffer = m_TextView.get_buffer();
+    auto buffer = m_TextView.get_buffer();
     buffer->set_text(message_from_worker_thread);
 
     // Scroll the last inserted line into view. That's somewhat complicated.
     Gtk::TextIter iter = buffer->end();
     iter.set_line_offset(0); // Beginning of last line
-    Glib::RefPtr<Gtk::TextMark> mark = buffer->get_mark("last_line");
+    auto mark = buffer->get_mark("last_line");
     buffer->move_mark(mark, iter);
     m_TextView.scroll_to(mark);
     // TextView::scroll_to(iter) is not perfect.
@@ -164,7 +164,7 @@ void ExampleWindow::on_notification_from_worker_thread()
   {
     // Work is done.
     m_WorkerThread->join();
-    m_WorkerThread = 0;
+    m_WorkerThread = nullptr;
     update_start_stop_buttons();
   }
   update_widgets();
