@@ -32,7 +32,8 @@ protected:
   void on_checkbutton_text();
   void on_checkbutton_activity();
   void on_checkbutton_inverted();
-  virtual bool on_timeout();
+
+  bool on_timeout();
   void on_button_close();
 
   //Child widgets:
