@@ -30,8 +30,8 @@ Canvas::~Canvas()
 {
   while(!m_canvas_items.empty())
   {
-    type_vec_items::iterator iter = m_canvas_items.begin();
-    CanvasItem* item = *iter;
+    auto iter = m_canvas_items.begin();
+    auto item = *iter;
     delete item;
     m_canvas_items.erase(iter);
   }
@@ -43,15 +43,15 @@ void Canvas::item_draw(const CanvasItem *item,
   const Cairo::RefPtr<Cairo::Context>& cr,
   bool preview)
 {
-  if(!item || !item->pixbuf)
+  if(!item || !item->m_pixbuf)
     return;
 
-  const double cx = item->pixbuf->get_width();
-  const double cy = item->pixbuf->get_height();
+  const double cx = item->m_pixbuf->get_width();
+  const double cy = item->m_pixbuf->get_height();
 
   Gdk::Cairo::set_source_pixbuf(cr,
-    item->pixbuf,
-    item->x - cx * 0.5, item->y - cy * 0.5);
+    item->m_pixbuf,
+    item->m_x - cx * 0.5, item->m_y - cy * 0.5);
 
   if(preview)
     cr->paint_with_alpha(0.6);
@@ -88,8 +88,8 @@ bool Canvas::on_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context,
   {
     // We already have a drop indicator so just update its position.
 
-    m_drop_item->x = x;
-    m_drop_item->y = y;
+    m_drop_item->m_x = x;
+    m_drop_item->m_y = y;
 
     queue_draw();
     context->drag_status(Gdk::ACTION_COPY, time);
@@ -115,30 +115,30 @@ void Canvas::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context
   int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time)
 {
   // Find the tool button which is the source of this DnD operation.
-  Gtk::Widget* widget = drag_get_source_widget(context);
+  auto widget = drag_get_source_widget(context);
 
-  Gtk::ToolPalette* drag_palette = dynamic_cast<Gtk::ToolPalette*>(widget);
+  auto drag_palette = dynamic_cast<Gtk::ToolPalette*>(widget);
   while(widget && !drag_palette)
   {
     widget = widget->get_parent();
     drag_palette = dynamic_cast<Gtk::ToolPalette*>(widget);
   }
 
-  Gtk::ToolItem* drag_item = 0;
+  Gtk::ToolItem* drag_item = nullptr;
   if(drag_palette)
     drag_item = drag_palette->get_drag_item(selection_data);
 
   // Create a drop indicator when a tool button was found:
-  Gtk::ToolButton* button = dynamic_cast<Gtk::ToolButton*>(drag_item);
+  auto button = dynamic_cast<Gtk::ToolButton*>(drag_item);
   if(!button)
     return;
 
   delete m_drop_item;
-  m_drop_item = 0;
+  m_drop_item = nullptr;
 
   try
   {
-    CanvasItem* item = new CanvasItem(this, button, x, y);
+    auto item = new CanvasItem(this, button, x, y);
 
     if(m_drag_data_requested_for_drop)
     {
@@ -193,7 +193,7 @@ void Canvas::on_drag_leave(const Glib::RefPtr<Gdk::DragContext>& context, guint
     return;
 
   delete m_drop_item;
-  m_drop_item = 0;
+  m_drop_item = nullptr;
 
   queue_draw();
 
