@@ -76,9 +76,9 @@ ExampleWindow::ExampleWindow()
           "%010d" /* 10 digits, using leading zeroes. */);
 
   //Display a progress bar instead of a decimal number:
-  Gtk::CellRendererProgress* cell = Gtk::manage(new Gtk::CellRendererProgress);
+  auto cell = Gtk::manage(new Gtk::CellRendererProgress);
   int cols_count = m_TreeView.append_column("Some percentage", *cell);
-  Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count - 1);
+  auto pColumn = m_TreeView.get_column(cols_count - 1);
   if(pColumn)
   {
     pColumn->add_attribute(cell->property_value(), m_Columns.m_col_percentage);
@@ -90,8 +90,8 @@ ExampleWindow::ExampleWindow()
   //finely control column drag and drop.
   for(guint i = 0; i < 2; i++)
   {
-    Gtk::TreeView::Column* pColumn = m_TreeView.get_column(i);
-    pColumn->set_reorderable();
+    auto column = m_TreeView.get_column(i);
+    column->set_reorderable();
   }
 
   show_all_children();
