@@ -43,7 +43,7 @@ TreeView_WithPopup::TreeView_WithPopup()
   append_column("Name", m_Columns.m_col_name);
 
   //Fill popup menu:
-  Gtk::MenuItem* item = Gtk::manage(new Gtk::MenuItem("_Edit", true));
+  auto item = Gtk::manage(new Gtk::MenuItem("_Edit", true));
   item->signal_activate().connect(
     sigc::mem_fun(*this, &TreeView_WithPopup::on_menu_file_popup_generic) );
   m_Menu_Popup.append(*item);
@@ -60,29 +60,24 @@ TreeView_WithPopup::TreeView_WithPopup()
 
   m_Menu_Popup.accelerate(*this);
   m_Menu_Popup.show_all(); //Show all menu items when the menu pops up
-
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  signal_button_press_event()
-    .connect(sigc::mem_fun(*this, &TreeView_WithPopup::on_button_press_event), false);
-#endif
 }
 
 TreeView_WithPopup::~TreeView_WithPopup()
 {
 }
 
-bool TreeView_WithPopup::on_button_press_event(GdkEventButton* event)
+bool TreeView_WithPopup::on_button_press_event(GdkEventButton* button_event)
 {
   bool return_value = false;
 
   //Call base class, to allow normal handling,
   //such as allowing the row to be selected by the right-click:
-  return_value = TreeView::on_button_press_event(event);
+  return_value = TreeView::on_button_press_event(button_event);
 
   //Then do our custom stuff:
-  if( (event->type == GDK_BUTTON_PRESS) && (event->button == 3) )
+  if( (button_event->type == GDK_BUTTON_PRESS) && (button_event->button == 3) )
   {
-    m_Menu_Popup.popup(event->button, event->time);
+    m_Menu_Popup.popup(button_event->button, button_event->time);
   }
 
   return return_value;
@@ -92,7 +87,7 @@ void TreeView_WithPopup::on_menu_file_popup_generic()
 {
   std::cout << "A popup menu item was selected." << std::endl;
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = get_selection();
+  auto refSelection = get_selection();
   if(refSelection)
   {
     Gtk::TreeModel::iterator iter = refSelection->get_selected();
