@@ -55,8 +55,8 @@ public:
 
 AppWindow::AppWindow()
 {
-  ArrowButton* button = 0;
-  Gtk::Grid* grid = 0;
+  ArrowButton* button = nullptr;
+  Gtk::Grid* grid = nullptr;
 
   set_title ("Arrow Buttons");
 
@@ -94,7 +94,7 @@ AppWindow::~AppWindow()
 
 int main (int argc, char *argv[])
 {
-  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
   AppWindow arrows;
 
   return app->run(arrows);
