@@ -26,7 +26,7 @@
 TicTacToe::TicTacToe()
 : Gtk::Box(Gtk::ORIENTATION_VERTICAL)
 {
-  Gtk::Grid* grid = Gtk::manage( new Gtk::Grid() );
+  auto grid = Gtk::manage( new Gtk::Grid() );
   grid->set_row_homogeneous(true);
   grid->set_column_homogeneous(true);
   add( *grid);
@@ -35,7 +35,7 @@ TicTacToe::TicTacToe()
   {
     for(int j=0;j<3; j++)
     {
-      Gtk::ToggleButton* button = 0;
+      Gtk::ToggleButton* button = nullptr;
       buttons[i][j] = button = Gtk::manage( new Gtk::ToggleButton());
       grid->attach(*button, i, j, 1, 1);
       button->signal_toggled().connect( sigc::bind(
